==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/FINDINGCLASSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FINDINGCLASSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FINDINGCLASSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FINDINGID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FINDINGCLASSID_Type", propOrder = {
    "classid",
    "findingid"
})
public class FINDINGCLASSID_Type {

    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "FINDINGID", required = true)
    protected FINDINGID_Type findingid;

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété findingid.
     * 
     * @return
     *     possible object is
     *     {@link FINDINGID_Type }
     *     
     */
    public FINDINGID_Type getFINDINGID() {
        return findingid;
    }

    /**
     * Définit la valeur de la propriété findingid.
     * 
     * @param value
     *     allowed object is
     *     {@link FINDINGID_Type }
     *     
     */
    public void setFINDINGID(FINDINGID_Type value) {
        this.findingid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/FINDINGCLASSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FINDINGCLASSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FINDINGCLASSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FINDINGID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FINDINGCLASSID_Type", propOrder = {
    "classid",
    "findingid"
})
public class FINDINGCLASSID_Type {

    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "FINDINGID", required = true)
    protected FINDINGID_Type findingid;

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the findingid property.
     * 
     * @return
     *     possible object is
     *     {@link FINDINGID_Type }
     *     
     */
    public FINDINGID_Type getFINDINGID() {
        return findingid;
    }

    /**
     * Sets the value of the findingid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FINDINGID_Type }
     *     
     */
    public void setFINDINGID(FINDINGID_Type value) {
        this.findingid = value;
    }

}
